==> brasero-3.12.1-arm-1_SBo.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/lib ; rm -rf libbrasero-utils3.so.1 )
( cd usr/lib ; ln -sf libbrasero-utils3.so.1.2.6 libbrasero-utils3.so.1 )
( cd usr/lib ; rm -rf libbrasero-media3.so.1 )
( cd usr/lib ; ln -sf libbrasero-media3.so.1.2.6 libbrasero-media3.so.1 )
( cd usr/lib ; rm -rf libbrasero-media3.so )
( cd usr/lib ; ln -sf libbrasero-media3.so.1.2.6 libbrasero-media3.so )
( cd usr/lib ; rm -rf libbrasero-burn3.so )
( cd usr/lib ; ln -sf libbrasero-burn3.so.1.2.6 libbrasero-burn3.so )
( cd usr/lib ; rm -rf libbrasero-burn3.so.1 )
( cd usr/lib ; ln -sf libbrasero-burn3.so.1.2.6 libbrasero-burn3.so.1 )
( cd usr/lib ; rm -rf libbrasero-utils3.so )
( cd usr/lib ; ln -sf libbrasero-utils3.so.1.2.6 libbrasero-utils3.so )
( cd usr/share/help/ca/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ca/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ca/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ca/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/pt_BR/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/pt_BR/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/hu/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/hu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/es/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/es/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/it/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/it/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/it/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/it/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/id/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/id/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/id/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/id/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/sv/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/sv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/sv/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/sv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/el/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/el/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/bg/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/bg/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/bg/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/bg/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/lv/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/lv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/fr/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/fr/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/zh_TW/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/zh_TW/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/zh_TW/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/zh_TW/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/te/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/te/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/te/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/te/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ko/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ko/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ja/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ja/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/cs/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/cs/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/cs/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/cs/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/en_GB/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/en_GB/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/en_GB/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/en_GB/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/sl/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/sl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/sl/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/sl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/de/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/de/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ru/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ru/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ru/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ru/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/gl/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/gl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/gl/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/gl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/zh_HK/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/zh_HK/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/zh_HK/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/zh_HK/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/eu/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/eu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/eu/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/eu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/fi/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/fi/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/fi/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/fi/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/zh_CN/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/zh_CN/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/zh_CN/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/zh_CN/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ro/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ro/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )

==> brasero-3.12.3-arm-1_SBo.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/lib ; rm -rf libbrasero-burn3.so )
( cd usr/lib ; ln -sf libbrasero-burn3.so.1.2.7 libbrasero-burn3.so )
( cd usr/lib ; rm -rf libbrasero-burn3.so.1 )
( cd usr/lib ; ln -sf libbrasero-burn3.so.1.2.7 libbrasero-burn3.so.1 )
( cd usr/lib ; rm -rf libbrasero-media3.so )
( cd usr/lib ; ln -sf libbrasero-media3.so.1.2.7 libbrasero-media3.so )
( cd usr/lib ; rm -rf libbrasero-media3.so.1 )
( cd usr/lib ; ln -sf libbrasero-media3.so.1.2.7 libbrasero-media3.so.1 )
( cd usr/lib ; rm -rf libbrasero-utils3.so )
( cd usr/lib ; ln -sf libbrasero-utils3.so.1.2.7 libbrasero-utils3.so )
( cd usr/lib ; rm -rf libbrasero-utils3.so.1 )
( cd usr/lib ; ln -sf libbrasero-utils3.so.1.2.7 libbrasero-utils3.so.1 )
( cd usr/share/help/bg/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/bg/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/bg/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/bg/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ca/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ca/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ca/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ca/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/cs/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/cs/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/cs/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/cs/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/da/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/da/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/da/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/da/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/de/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/de/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/de/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/de/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/el/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/el/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/el/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/el/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/en_GB/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/en_GB/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/en_GB/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/en_GB/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/es/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/es/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/es/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/es/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/eu/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/eu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/eu/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/eu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/fi/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/fi/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/fi/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/fi/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/fr/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/fr/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/fr/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/fr/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/gl/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/gl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/gl/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/gl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/hu/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/hu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/hu/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/hu/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/id/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/id/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/id/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/id/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/it/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/it/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/it/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/it/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ja/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ja/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ja/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ja/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ko/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ko/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ko/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ko/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/lv/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/lv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/lv/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/lv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/pl/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/pl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/pl/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/pl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/pt/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/pt/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/pt/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/pt/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/pt_BR/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/pt_BR/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/pt_BR/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/pt_BR/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ro/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ro/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ro/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ro/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/ru/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/ru/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/ru/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/ru/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/sl/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/sl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/sl/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/sl/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/sv/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/sv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/sv/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/sv/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/te/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/te/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/te/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/te/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/uk/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/uk/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/uk/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/uk/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/zh_CN/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/zh_CN/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/zh_CN/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/zh_CN/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/zh_HK/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/zh_HK/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/zh_HK/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/zh_HK/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
( cd usr/share/help/zh_TW/brasero/figures ; rm -rf brasero-main-window.png )
( cd usr/share/help/zh_TW/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/brasero-main-window.png brasero-main-window.png )
( cd usr/share/help/zh_TW/brasero/figures ; rm -rf logo48.png )
( cd usr/share/help/zh_TW/brasero/figures ; ln -sf /usr/share/help/C/brasero/figures/logo48.png logo48.png )
